@@ -1,20 +1,30 @@
 """
-Set of routinges to work with musical pitches, convert
-to and from frequencies, notenames, etc.
+Set of routines to work with musical pitches, convert to and from frequencies, 
+notenames, etc.
+
+Global settings vs Converter objects
+====================================
+
+In order to customize settings like the frequency of A4, it is possible
+to either set that value globally (via, for example, :func:`pitchtools.set_reference_freq`)
+or create a custom :class:`~pitchtools.Converter`
 
-There is a set of functions which all follow global settings
-regarding, for example, the frequency for A4. In order to use
-a custom value without interfering with any other clients of
-the library, create a custom Converter
 
 Example
-=======
+-------
 
 .. code::
 
+    # Set the value globally
+    >>> set_reference_freq(443)
+    >>> n2f("A4")
+    443.0
+
+    # Create a Converter object
     >>> cnv = Converter(a4=435)
     >>> print(cnv.n2f("4C"))
     258.7
+
 """
 
 from __future__ import annotations
@@ -41,10 +51,10 @@ _r2 = _re.compile(r"(?P<oct>[-]?\d+)(?P<pch>[A-Ha-h][b|#]?)(?P<micro>[-+><↓↑
 class NoteParts(NamedTuple):
     """
     Attributes:
-        octave: octave number, 4=central octave
-        noteName: "C", "D", "E", ... (diatonic step)
-        alteration: the alteration as str, "#", "b", "+", "-", ">", "<"
-        centsDeviation: number of cents deviation from the chromatic pitch
+        octave (int): octave number, 4=central octave
+        noteName (str: "C", "D", "E", ... (diatonic step)
+        alteration (str): the alteration as str, "#", "b", "+", "-", ">", "<"
+        centsDeviation (int): number of cents deviation from the chromatic pitch
     """
     octave: int
     noteName: str
@@ -60,10 +70,10 @@ class NoteParts(NamedTuple):
 class ParsedMidinote(NamedTuple):
     """
     Attributes:
-        pitchindex: 0=C, 1=C#, ...
-        deviation: in semitones, deviation from the chromatic pitch
-        octave: 4 = central octave
-        chromatic_pitch: the written pitch, "Eb", "F#", etc. No microtones
+        pitchindex (int): 0=C, 1=C#, ...
+        deviation (float): in semitones, deviation from the chromatic pitch
+        octave (int): 4 = central octave
+        chromatic_pitch (str): the written pitch, "Eb", "F#", etc. No microtones
     """
     pitchindex: int
     deviation: float
@@ -94,44 +104,76 @@ class NotatedPitch(NamedTuple):
 
 
 class Converter:
-    def __init__(self, a4=442.0, eightnote_symbol=True):
-        """
-        Convert between midinote, frequency and notename.
+    """
+    Convert between midinote, frequency and notename.
 
-        Args:
-            a4: the reference frequency
-            eightnote_symbol: if True, a special symbol is used
-                (">", "<") when a note is exactly 25 cents higher
-                or lower (for example, "4C>"). Otherwise, a notename
-                would be, for example, "4C+25"
-        """
+    Args:
+        a4: the reference frequency
+        eightnote_symbol: if True, a special symbol is used
+            (">", "<") when a note is exactly 25 cents higher
+            or lower (for example, "4C>"). Otherwise, a notename
+            would be, for example, "4C+25"
+    """
+
+    def __init__(self, a4=442.0, eightnote_symbol=True):
         self.a4 = a4
         self.eighthnote_symbol = eightnote_symbol
 
     def set_reference_freq(self, a4:float) -> None:
+        """
+        Set the reference freq. (the freq. of A4) for this converter
+
+        Args:
+            a4: the freq. of A4 in Hz
+        """
         self.a4 = a4
 
     def get_reference_freq(self) -> float:
+        """
+        Get the reference frequency for this converter
+
+        Returns:
+            the freq. of A4
+        """
         return self.a4
 
     def f2m(self, freq: float) -> float:
         """
         Convert a frequency in Hz to a midi-note
 
-        See also: set_reference_freq, temporaryA4
+        Args:
+            freq: the frequency to convert, in Hz
+
+        Returns:
+            the midi note corresponding to freq
+
+        **See also**: :meth:`~Converter-set_reference_freq`
         """
         if freq<9:
             return 0
         return 12.0*math.log(freq/self.a4, 2)+69.0
 
     def freqround(self, freq:float) -> float:
+        """
+        Round the freq. to the nearest midinote
+
+        Args:
+            freq: the freq. to round
+
+        Returns:
+            the rounded frequency
+        """
         return self.m2f(round(self.f2m(freq)))
 
     def m2f(self, midinote: float) -> float:
         """
         Convert a midi-note to a frequency
 
-        See also: set_reference_freq, temporaryA4
+        Args:
+            midinote: the midinote to convert to frequency
+
+        Returns:
+            the freq. corresponding to midinote
         """
         return 2**((midinote-69)/12.0)*self.a4
 
@@ -159,12 +201,31 @@ class Converter:
             return f"{octave}{note}{microtonal_alteration}{cents}"
 
     def n2m(self, note: str) -> float:
+        """ 
+        Convert a notename to a midinote 
+
+        Args:
+            note: the notename
+
+        Returns:
+            the midinote corresponding to note
+        """
         return n2m(note)
 
     def n2f(self, note: str) -> float:
+        """ Convert a notename to its corresponding frequency """
         return self.m2f(n2m(note))
 
     def f2n(self, freq: float) -> str:
+        """ 
+        Return the notename corresponding to the given freq 
+
+        Args:
+            freq: the freq. to convert
+
+        Returns:
+            the corresponding notename
+        """
         return self.m2n(self.f2m(freq))
 
     def pianofreqs(self, start="A0", stop="C8") -> List[float]:
@@ -185,6 +246,26 @@ class Converter:
         return freqs
 
     def asmidi(self, x:U[int, float, str]) -> float:
+        """ 
+        Convert x to a midinote 
+
+        Args:
+            x: an object which can be converted to a midinote (a freq., a notename)
+
+        Returns:
+            The corresponding midinote.
+
+        Example
+        -------
+
+        .. code::
+
+            >>> from pitchtools import *
+            >>> cnv = Converter()
+            >>> cnv.asmidi("4C+10Hz")
+            272.8
+
+        """
         if isinstance(x, str):
             return self.str2midi(x)
         else:
@@ -192,14 +273,15 @@ class Converter:
 
     def str2midi(self, s: str) -> float:
         """
-        Accepts all that n2m accepts but with the addition of
-        frequencies
+        Accepts all that n2m accepts but with the addition of frequencies
 
-        Possible values:
+        Args:
+            s: pitch describes as a string. Possible values: "100hz", "4F+20hz", "8C-4hz"
 
-        "100hz", "200Hz", "4F+20hz", "8C-4hz"
+        Returns:
+            the corresponding midinote
 
-        The hz part must be at the end
+        **NB**: The hz part must be at the end
         """
         ending = s[-2:]
         if ending != "hz" and ending != "Hz":
@@ -226,8 +308,7 @@ class Converter:
 
     def midi_to_note_parts(self, midinote: float) -> NoteParts:
         """
-        Convert a midinote into its parts as a note: 
-            octave, notename, alteration, cents deviation
+        Convert a midinote into its parts as a note
 
         Args:
             midinote: the midinote to analyze
@@ -268,6 +349,24 @@ class Converter:
             return NoteParts(octave, _sharps[ps], "", cents)
 
     def normalize_notename(self, notename: str) -> str:
+        """ 
+        Convert notename to its canonical form 
+
+        Args:
+            notename: the note to normalize
+
+        Returns:
+            the normalized notename
+
+        Example
+        -------
+
+        .. code::
+
+            >>> normalize_notename("a4+24")
+            4A+24
+
+        """
         return self.m2n(self.n2m(notename))
 
 
@@ -275,16 +374,22 @@ def n2m(note: str) -> float:
     """
     Convert a notename to a midinote
 
-    Two formats are supported (the 2nd format is preferable:
+    Args:
+        note: the notename
+
+    Returns:
+        the corresponding midi note
+
+    Two formats are supported:
 
     * 1st format: ``C#2``, ``D4``, ``Db4+20``, ``C4>``, ``Eb5<``
     * 2nd format: ``2C#``, ``4D+``, ``7Eb-14``
 
-    **NB**: the second format, with its clear hierarchy ``octave:pitch:microtone`` is
-    preferred
+    .. note::
+
+        The second format, with its clear hierarchy ``octave:pitch:microtone`` is
+        the canonical one and used when converting a midinote to a notename
 
-    Some examples
-    ~~~~~~~~~~~~~
 
     ========      ========
     Input         Output
@@ -382,8 +487,14 @@ def _pitchname(pitchidx: int, micro: float) -> str:
 
 def parse_midinote(midinote: float) -> ParsedMidinote:
     """
-    Convert a midinote into its pitch components:
-        pitchindex, deviation, octave, chromaticPitch
+    Convert a midinote into its pitch components
+
+    Args:
+        midinote: the midinote, where 60 corresponds to central C (C4)
+
+    Returns:
+        a ParsedMidinote, which is a NamedTuple with fields pitchindex (int), 
+        deviation (in semitones, float), octave (int) and chromaticPitch (str)
 
     ======    =========
     Input     Output
@@ -415,23 +526,49 @@ def parse_midinote(midinote: float) -> ParsedMidinote:
 
 def ratio2interval(ratio: float) -> float:
     """
-    Given two frequencies f1 and f2, calculate the interval between them
+    Convert the ratio between 2 freqs. to their interval in semitones
+    
+    Args:
+        ratio: a ratio between two frequencies
+
+    Returns:
+        The interval (in semitones) between those frequencies
+
+    Example
+    =======
+    
+    .. code::
+    
+        >>> f1 = n2f("C4")
+        >>> f2 = n2f("D4")
+        >>> ratio2interval(f2/f1)   
+        2
 
-    f1 = n2f("C4")
-    f2 = n2f("D4")
-    interval = ratio2interval(f2/f1)   # --> 2 (semitones)
     """
     return 12 * math.log(ratio, 2)
 
 
 def interval2ratio(interval: float) -> float:
     """
-    Calculate the ratio r so that f1*r gives f2 so that
-    the interval between f2 and f1 is the given one
+    Convert a semitone interval to a ratio between 2 freqs.
+
+    Args:
+        interval: an interval in semitones
+
+    Returns:
+        the ratio between frequencies corresponding to the given interval
+
+
+    Example
+    =======
+
+    .. code::
+
+        >>> f1 = n2f("C4")
+        >>> r = interval2ratio(7)  # a 5th higher
+        >>> f2n(f1*r)  
+        4G
 
-    f1 = n2f("C4")
-    r = interval2ratio(7)  # a 5th higher
-    f2 = f2n(f1*r)  # --> G4
     """
     return 2 ** (interval / 12.0)
 
@@ -443,8 +580,7 @@ i2r = interval2ratio
 def quantize_midinote(midinote: float, divisions_per_semitone, method="round"
                       ) -> float:
     """
-    Quantize midinote to the next pitch in grid accordingto the semitone divisions
-    given.
+    Quantize midinote to the next semitone division
 
     Args:
         midinote: the midinote to round
@@ -468,8 +604,24 @@ def quantize_midinote(midinote: float, divisions_per_semitone, method="round"
 
 def quantize_notename(notename: str, divisions_per_semitone) -> str:
     """
-    Quantize notename to the next pitch in grid according to the semitone
-    divisions given.
+    Quantize notename to the next semitone divisions
+
+    Args:
+        notename: the notename to quantize
+        divisions_per_semitone: the number of divisions of the semitone 
+            (1 to quantize to nearest chromatic note)
+
+    Returns:
+        the notename of the quantized pitch
+
+    Example
+    -------
+
+    .. code::
+
+        >>> quantize_notename("4A+18", 4)
+        4A+25
+
 
     See Also:
         `quantize_midinote`
@@ -529,6 +681,13 @@ def construct_notename(octave:int, letter:str, alter:U[int, str], cents:int,
 def pitchbend2cents(pitchbend: int, maxcents=200) -> int:
     """
     Convert a MIDI pitchbend to its corresponding deviation in cents
+
+    Args:
+        pitchbend: the MIDI pitchbend value, between 0-16383 (8192 = 0 semitones)
+        maxcents: the cents corresponding to the max. bend
+
+    Returns:
+        the bend expressed in cents
     """
     return int(((pitchbend / 16383.0) * (maxcents * 2.0)) - maxcents + 0.5)
 
@@ -536,6 +695,13 @@ def pitchbend2cents(pitchbend: int, maxcents=200) -> int:
 def cents2pitchbend(cents: int, maxcents=200) -> int:
     """
     Convert a deviation in cents to the corresponding value as pitchbend.
+
+    Args:
+        cents: the bend interval, in cents
+        maxcents: the cents corresponding to the max. bend
+
+    Returns:
+        the bend MIDI value (between 0-16383)
     """
     return int((cents + maxcents) / (maxcents * 2.0) * 16383.0 + 0.5)
 
@@ -557,6 +723,34 @@ _centsrepr = {
 }
 
 def alteration_to_cents(alteration: str) -> int:
+    """
+    Convert an alteration to its corresponding cents deviation
+
+    Args:
+        alteration: the alteration as str (see table below)
+
+    Returns:
+        the alteration in cents
+
+    =============  =======
+     Alternation    Cents
+    =============  =======
+        #+          150
+        #>          125
+        #           100
+        #<          75
+        \+          50
+        >           25
+        <           -25
+        \-          -50
+        b>          -75
+        b           -100
+        b<          -125
+        b-          -150
+    =============  =======
+    
+
+    """
     cents = _centsrepr.get(alteration)
     if cents is None:
         raise ValueError(f"Unknown alteration: {alteration}, "
@@ -576,6 +770,7 @@ def _parse_centstr(centstr: str) -> int:
 def split_notename(notename: str) -> Tuple[int, str, str, int]:
     """
     Return (octave, letter, alteration (#, b), cents)
+
     Microtonal alterations, like "+", "-", ">", "<" are resolved
     into cents alterations
 
@@ -630,8 +825,16 @@ def split_notename(notename: str) -> Tuple[int, str, str, int]:
 
 def split_cents(notename: str) -> Tuple[str, int]:
     """
-    Split a notename into the chromatic note and the cents deviation,
-    as a negative or possitive integer
+    Split a notename into the chromatic note and the cents deviation.
+
+    The cents deviation can be a negative or possitive integer
+
+    Args:
+        notename: the notename to split
+
+    Returns:
+        the chromatic pitch and the cents deviation from this chromatic pitch
+
 
     ========   ============
     Input      Output
@@ -648,9 +851,18 @@ def split_cents(notename: str) -> Tuple[str, int]:
 
 def enharmonic(notename: str) -> str:
     """
-    Return the enharmonic version of notename. Notes without an alteration
-    have no enharmonic (double alterations are never used)
+    Return the enharmonic version of notename. 
 
+    Notes without an alteration have no enharmonic 
+    (double alterations are never used)
+
+
+    Args:
+        notename: the notename to find an enharmonic to
+
+    Returns:
+        the enharmonic version of the note (this can be the
+        same as the original)
 
     ==========     ============
     original       enharmonic
@@ -701,8 +913,9 @@ def enharmonic(notename: str) -> str:
 
 def pitch_round(midinote: float, semitoneDivisions=4) -> Tuple[str,int]:
     """
-    Round midinote to the next (possibly microtonal) pitch according to
-    semitoneDivisions. Returns the rounded notename and the cents deviation
+    Round midinote to the next (possibly microtonal) pitch
+
+    Returns the rounded notename and the cents deviation
     from the original pitch to the next semitone
 
     Args:
@@ -712,13 +925,16 @@ def pitch_round(midinote: float, semitoneDivisions=4) -> Tuple[str,int]:
     Returns:
         a tuple (rounded note, cents deviation)
 
-    Example::
+    Example
+    =======
 
+    .. code::
+        
         >>> pitch_round(60.1)
         ("4C", 10)
-
         >>> pitch_round(60.75)
         ("4D<", -25)
+        
     """
     rounding_factor = 1 / semitoneDivisions
     rounded_midinote = round(midinote/rounding_factor)*rounding_factor
@@ -744,6 +960,13 @@ def mel2freq(mel:float) -> float:
     """
     Convert a position in the mel-scale to its corresponding frequency
 
+    Args:
+        mel: the mel index (can be fractional)
+
+    Returns:
+        the corresponding freq. in Hz
+
+
     .. note::
         The mel scale is a perceptual scale of pitches judged by listeners to be
         equal in distance from one another
@@ -868,7 +1091,8 @@ def db2amp(db: float) -> float:
     """
     convert dB to amplitude (0, 1)
 
-    db: a value in dB
+    Args:
+        db: a value in dB
     """
     return 10.0 ** (0.05 * db)
 
@@ -877,11 +1101,13 @@ def amp2db(amp: float) -> float:
     """
     convert amp (0, 1) to dB
 
-    20.0 * log10(amplitude)
+    ``20.0 * log10(amplitude)``
 
-    :type amp: float|np.ndarray
-    :rtype: float|np.ndarray
+    Args:
+        amp: the amplitude between 0 and 1
 
+    Returns: 
+        the corresponding amplitude in dB
     """
     amp = max(amp, _EPS)
     return math.log10(amp) * 20
